#!/usr/bin/perl
#
#   Program to process latex files and
#    add section/subsection/subsubsection numbers
#    figure numbers, and table numbers
#    as comments next to the section/figure/table
#    commands.
#
#       Blake Hannaford
#       University of Washington
#       July 2001
#
#       Modified to work with Platypus
#       Ramon M. Figueroa-Centeno
#       University of Hawai'i at Hilo
#       October 2004
#

$cnt = 0;

# loop through list of files dropped
foreach(@ARGV)
{
	if ($cnt != 0) # We ignore the first argument (the app bundle path)
	{
		#$file = shift @ARGV;
		$file = $_;
		
		printf STDERR "Opening $file\n";
		
		open (IFHANDLE, "<$file") || ((die ("Can't open [$file]: $!\n") ));
		
		
		open (OFHANDLE, ">sectex.t") or die("Can't open temp file [./sectex.t]: $!\n");
		
		
		$idstring =  "%%%%** Section";
		$idstringF = "%%%%** Figure";
		$idstringT = "%%%%** Table";
		
		$line = 0;
		
		# initialize counters
		$sec = 0;
		$subsec = 0;
		$subsubsec = 0;
		$fig = 0;
		$table = 0;
		
		while (<IFHANDLE>)
		  {
		   chomp;                   # get rid of newline
		
		   if(m/^%%%%\*\* Section/) { next; }     # Detect old section comments
												  #   and delete them
		   if(m/^%%%%\*\* Figure/) { next; }      # Detect old Figure comments
												  #   and delete them
		   if(m/^%%%%\*\* Table/) { next; }       # Detect old Table comments
												  #   and delete them
			# nb the above regexps must match $idstringX (hack!)
		
			
		  $line = $_;                           # store original line
			
		  @pieces = split /%/, $_, 2 ;            # get rid of comments
		  $_ = @pieces[0];                   # don't check comments!
		
		
				#####################
				#
				#    Sections and subsections
				#
				if(m/\\section\s*\{/) {          # Detect ``section''
				$sec++;
				$subsec = 0;
				$subsubsec = 0;
				printf OFHANDLE "%s %s\n", $idstring, $sec;
				}
		
				if(m/\\subsection\s*\{/) {       # Detect ``subsection''
				$subsec++;
				$subsubsec = 0;
				printf OFHANDLE  "%s %s.%s\n", $idstring, $sec, $subsec;
				}
		
				if(m/\\subsubsection\s*\{/) {    # Detect ``subsubsection''
				$subsubsec++;
				printf OFHANDLE  "%s %s.%s.%s\n", $idstring, $sec, $subsec, $subsubsec;
				}
		
				#######################
				#
				#  Figures
				#
				if(m/\\begin\{figure/) {          # Detect figure
				#printf ">>>> Found Figure \n";
				$fig++;
				
				#print "Found Figure $fig:   $idstringF\n";
				
				printf OFHANDLE  "%s %s\n", $idstringF, $fig ;
				}
		
				#######################
				#
				#  Tables
				#
				if(m/\\begin\{table/) {          # Detect table
				$table++;
				printf OFHANDLE  "%s %s\n", $idstringT, $table;
				}
		
		
		   printf OFHANDLE  "%s\n", $line;
		
		  }
		
		close(OFHANDLE);
		close($IFHANDLE);
		
		system("mv sectex.t $file");
		
		
		#exit 1;

	}
	$cnt++;
}